pub enum ElementKind {
Other = 0,
Test = 1,
Module = 2,
Function = 3,
Variable = 4,
Const = 5,
Type = 6,
Field = 7,
Trait = 8,
FunctionSignature = 9,
}Expand description
Defines supported element kinds. [req(“trace.element.kind”)]
Variants
Other = 0
Variant that should be used if no other one fits.
Test = 1
Marks an element as a test or test case.
Module = 2
A module or package.
Function = 3
A function or method.
Variable = 4
A variable or static.
Const = 5
A constant.
Type = 6
A type, struct, enum, class, or union.
Field = 7
A field or property.
Trait = 8
A trait, interface, or other abstract type.
FunctionSignature = 9
A function signature or virtual function that has no body. It is likely declared inside a trait/interface.
Implementations