pub struct AnnotationSchema {
pub schema_version: Option<String>,
pub files: Vec<FileAnnotations>,
pub trace_properties: Option<Properties>,
pub origin: Option<Origin>,
}Expand description
Defines the schema to exchange mantra annotation related information. [req(“exchange.traces.schema”)]
Fields
schema_version: Option<String>The schema version. [req(“exchange.versioned”)]
files: Vec<FileAnnotations>List of files that contain mantra annotations.
trace_properties: Option<Properties>Optional properties related to detected traces in all files in this entry.
Note: If a trace sets a property key directly, the value set at the trace will be taken.
origin: Option<Origin>Optional base origin of the files in this entry. e.g. specific branch or commit from a git repository