pub struct CoverageExclude {
pub kind: CoverageExcludeKind,
pub comment: String,
}Expand description
Coverage exclusion information found in a file. e.g. markers in code files may be used to exclude uncoverable lines from being considered for code coverage metrics.
TODO: add requirement trace
Fields
kind: CoverageExcludeKindThe kind of coverage exclusion.
comment: StringMandatory comment on why the exclusion is acceptable.
Implementations
Sourceimpl CoverageExclude
impl CoverageExclude
Sourcepub fn start_line(&self) -> Line
pub fn start_line(&self) -> Line
The start line the coverage exclusion starts.