pub struct ResolvedAnnotations {
pub traces: Option<Vec<ResolvedTrace>>,
pub elements: Option<Vec<ResolvedElement>>,
pub coverage_excludes: Option<Vec<CoverageExclude>>,
}Fields
traces: Option<Vec<ResolvedTrace>>elements: Option<Vec<ResolvedElement>>coverage_excludes: Option<Vec<CoverageExclude>>Trait Implementations
Sourceimpl Clone for ResolvedAnnotations
impl Clone for ResolvedAnnotations
Sourcefn clone(&self) -> ResolvedAnnotations
fn clone(&self) -> ResolvedAnnotations
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResolvedAnnotations
impl Debug for ResolvedAnnotations
Sourceimpl<'de> Deserialize<'de> for ResolvedAnnotations
impl<'de> Deserialize<'de> for ResolvedAnnotations
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResolvedAnnotations
impl JsonSchema for ResolvedAnnotations
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ResolvedAnnotations
impl PartialEq for ResolvedAnnotations
Sourcefn eq(&self, other: &ResolvedAnnotations) -> bool
fn eq(&self, other: &ResolvedAnnotations) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ResolvedAnnotations
impl Serialize for ResolvedAnnotations
impl StructuralPartialEq for ResolvedAnnotations