pub struct ResolvedTrace {
pub resolved_ids: Vec<RequirementReference>,
pub unknown_ids: Vec<ReqId>,
pub line: Line,
pub related_code: Option<TraceRelatedCodeVariant>,
pub kind: TraceKind,
pub properties: Option<Properties>,
}Fields
resolved_ids: Vec<RequirementReference>The requirement IDs that are referenced by the trace. [req(“trace.id”, “trace.mult_reqs”)]
unknown_ids: Vec<ReqId>line: LineThe line the trace is defined at. [req(“trace.origin”)]
Optional related code block or element that is linked to the trace. [req(“trace.code_block”, “trace.element”)]
kind: TraceKindTrace kind. [req(“trace.kind`”)]
properties: Option<Properties>List of custom properties that may be set on a trace. [req(“trace.properties”)]