pub struct TraceReference {
pub filepath: RelativePathBuf,
pub file_hash: FmtHash,
pub line: Line,
pub kind: TraceKind,
}Fields
filepath: RelativePathBuffile_hash: FmtHashline: Linekind: TraceKindTrait Implementations
Sourceimpl Clone for TraceReference
impl Clone for TraceReference
Sourcefn clone(&self) -> TraceReference
fn clone(&self) -> TraceReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TraceReference
impl Debug for TraceReference
Sourceimpl<'de> Deserialize<'de> for TraceReference
impl<'de> Deserialize<'de> for TraceReference
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TraceReference
Sourceimpl Hash for TraceReference
impl Hash for TraceReference
Sourceimpl JsonSchema for TraceReference
impl JsonSchema for TraceReference
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TraceReference
impl PartialEq for TraceReference
Sourcefn eq(&self, other: &TraceReference) -> bool
fn eq(&self, other: &TraceReference) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TraceReference
impl Serialize for TraceReference
impl StructuralPartialEq for TraceReference