pub struct ResolvedOverrideFileCoverage {
pub filepath: RelativePathBuf,
pub lines: Vec<ResolvedOverrideCoveredLineInfo>,
}Fields
filepath: RelativePathBuflines: Vec<ResolvedOverrideCoveredLineInfo>Trait Implementations
Sourceimpl Clone for ResolvedOverrideFileCoverage
impl Clone for ResolvedOverrideFileCoverage
Sourcefn clone(&self) -> ResolvedOverrideFileCoverage
fn clone(&self) -> ResolvedOverrideFileCoverage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResolvedOverrideFileCoverage
impl Debug for ResolvedOverrideFileCoverage
Sourceimpl<'de> Deserialize<'de> for ResolvedOverrideFileCoverage
impl<'de> Deserialize<'de> for ResolvedOverrideFileCoverage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ResolvedOverrideFileCoverage
Sourceimpl Hash for ResolvedOverrideFileCoverage
impl Hash for ResolvedOverrideFileCoverage
Sourceimpl JsonSchema for ResolvedOverrideFileCoverage
impl JsonSchema for ResolvedOverrideFileCoverage
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ResolvedOverrideFileCoverage
impl PartialEq for ResolvedOverrideFileCoverage
Sourcefn eq(&self, other: &ResolvedOverrideFileCoverage) -> bool
fn eq(&self, other: &ResolvedOverrideFileCoverage) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ResolvedOverrideFileCoverage