pub enum ResolvedLineState {
Covered(Vec<CoveredLineTestReference>),
Excluded(Option<ExclusionAnnotationReference>),
Overriden(Vec<ReviewOverride>),
Uncovered,
}Variants
Covered(Vec<CoveredLineTestReference>)
Excluded(Option<ExclusionAnnotationReference>)
Line was excluded from coverage analysis. An optional reference to an exclusion annotation is given, if the exclusion was based on a mantra annotation.
Overriden(Vec<ReviewOverride>)
Uncovered