pub struct CoveredLineTestReference {
pub test: TestReference,
pub hits: i64,
}Fields
test: TestReferencehits: i64Trait Implementations
Sourceimpl Clone for CoveredLineTestReference
impl Clone for CoveredLineTestReference
Sourcefn clone(&self) -> CoveredLineTestReference
fn clone(&self) -> CoveredLineTestReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CoveredLineTestReference
impl Debug for CoveredLineTestReference
Sourceimpl<'de> Deserialize<'de> for CoveredLineTestReference
impl<'de> Deserialize<'de> for CoveredLineTestReference
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CoveredLineTestReference
Sourceimpl Hash for CoveredLineTestReference
impl Hash for CoveredLineTestReference
Sourceimpl JsonSchema for CoveredLineTestReference
impl JsonSchema for CoveredLineTestReference
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CoveredLineTestReference
impl PartialEq for CoveredLineTestReference
Sourcefn eq(&self, other: &CoveredLineTestReference) -> bool
fn eq(&self, other: &CoveredLineTestReference) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CoveredLineTestReference
impl Serialize for CoveredLineTestReference
impl StructuralPartialEq for CoveredLineTestReference