pub struct ExclusionAnnotationReference {
pub def_line: Line,
pub comment: String,
}Fields
def_line: LineThe line the exclude annotation was defined at.
comment: StringTrait Implementations
Sourceimpl Clone for ExclusionAnnotationReference
impl Clone for ExclusionAnnotationReference
Sourcefn clone(&self) -> ExclusionAnnotationReference
fn clone(&self) -> ExclusionAnnotationReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExclusionAnnotationReference
impl Debug for ExclusionAnnotationReference
Sourceimpl<'de> Deserialize<'de> for ExclusionAnnotationReference
impl<'de> Deserialize<'de> for ExclusionAnnotationReference
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExclusionAnnotationReference
Sourceimpl Hash for ExclusionAnnotationReference
impl Hash for ExclusionAnnotationReference
Sourceimpl JsonSchema for ExclusionAnnotationReference
impl JsonSchema for ExclusionAnnotationReference
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExclusionAnnotationReference
impl PartialEq for ExclusionAnnotationReference
Sourcefn eq(&self, other: &ExclusionAnnotationReference) -> bool
fn eq(&self, other: &ExclusionAnnotationReference) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExclusionAnnotationReference