pub struct SourceLineInfo {
pub nr: Line,
pub state: ResolvedLineState,
}Expand description
Coverage information of a line in a file. [req(“testcov.cov.lines”)]
Fields
nr: LineThe line number.
state: ResolvedLineStateTrait Implementations
Sourceimpl Clone for SourceLineInfo
impl Clone for SourceLineInfo
Sourcefn clone(&self) -> SourceLineInfo
fn clone(&self) -> SourceLineInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SourceLineInfo
impl Debug for SourceLineInfo
Sourceimpl<'de> Deserialize<'de> for SourceLineInfo
impl<'de> Deserialize<'de> for SourceLineInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SourceLineInfo
Sourceimpl Hash for SourceLineInfo
impl Hash for SourceLineInfo
Sourceimpl JsonSchema for SourceLineInfo
impl JsonSchema for SourceLineInfo
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SourceLineInfo
impl PartialEq for SourceLineInfo
Sourcefn eq(&self, other: &SourceLineInfo) -> bool
fn eq(&self, other: &SourceLineInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SourceLineInfo
impl Serialize for SourceLineInfo
impl StructuralPartialEq for SourceLineInfo