pub struct SourceChildReference {
pub collected_by: Vec<ProductId>,
pub name: String,
}Fields
collected_by: Vec<ProductId>name: StringTrait Implementations
Sourceimpl Clone for SourceChildReference
impl Clone for SourceChildReference
Sourcefn clone(&self) -> SourceChildReference
fn clone(&self) -> SourceChildReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SourceChildReference
impl Debug for SourceChildReference
Sourceimpl<'de> Deserialize<'de> for SourceChildReference
impl<'de> Deserialize<'de> for SourceChildReference
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SourceChildReference
impl JsonSchema for SourceChildReference
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SourceChildReference
impl PartialEq for SourceChildReference
Sourcefn eq(&self, other: &SourceChildReference) -> bool
fn eq(&self, other: &SourceChildReference) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SourceChildReference
impl Serialize for SourceChildReference
impl StructuralPartialEq for SourceChildReference