pub struct SourceFolderReportSchema {
pub schema_version: Option<String>,
pub path: RelativePathBuf,
pub folder: Option<Vec<SourceChildReference>>,
pub files: Option<Vec<SourceChildReference>>,
pub product_coverage: Option<Vec<SourceFolderProductCoverage>>,
pub collected_by: Vec<ProductMetadata>,
}Fields
schema_version: Option<String>The schema version. [req(“exchange.versioned”)]
path: RelativePathBuffolder: Option<Vec<SourceChildReference>>files: Option<Vec<SourceChildReference>>product_coverage: Option<Vec<SourceFolderProductCoverage>>collected_by: Vec<ProductMetadata>Trait Implementations
Sourceimpl Clone for SourceFolderReportSchema
impl Clone for SourceFolderReportSchema
Sourcefn clone(&self) -> SourceFolderReportSchema
fn clone(&self) -> SourceFolderReportSchema
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SourceFolderReportSchema
impl Debug for SourceFolderReportSchema
Sourceimpl<'de> Deserialize<'de> for SourceFolderReportSchema
impl<'de> Deserialize<'de> for SourceFolderReportSchema
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SourceFolderReportSchema
impl JsonSchema for SourceFolderReportSchema
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SourceFolderReportSchema
impl PartialEq for SourceFolderReportSchema
Sourcefn eq(&self, other: &SourceFolderReportSchema) -> bool
fn eq(&self, other: &SourceFolderReportSchema) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SourceFolderReportSchema
impl Serialize for SourceFolderReportSchema
impl StructuralPartialEq for SourceFolderReportSchema