pub enum TestState {
Failed = 0,
Passed = 1,
Skipped = 2,
Unknown = 3,
Obsolete = 4,
}Expand description
Possible states a test run or test case may be in.
Variants
Failed = 0
Test failed.
Passed = 1
Test passed successfully.
Skipped = 2
Test was skipped in the related test run.
Unknown = 3
Test is in an unknown state.
This likely indicates that a test case did not finish execution, and is treated as failed state. [req(“testcov.test_case.state.unknown”)]
Obsolete = 4
Test is obsolete.
Obsolete tests must not be considered for coverage analysis.
Implementations