pub struct TestCoverageSummary {
pub lines: CoverageSummary,
}Fields
lines: CoverageSummaryTrait Implementations
Sourceimpl Clone for TestCoverageSummary
impl Clone for TestCoverageSummary
Sourcefn clone(&self) -> TestCoverageSummary
fn clone(&self) -> TestCoverageSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TestCoverageSummary
impl Debug for TestCoverageSummary
Sourceimpl Default for TestCoverageSummary
impl Default for TestCoverageSummary
Sourcefn default() -> TestCoverageSummary
fn default() -> TestCoverageSummary
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TestCoverageSummary
impl<'de> Deserialize<'de> for TestCoverageSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TestCoverageSummary
impl JsonSchema for TestCoverageSummary
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TestCoverageSummary
impl PartialEq for TestCoverageSummary
Sourcefn eq(&self, other: &TestCoverageSummary) -> bool
fn eq(&self, other: &TestCoverageSummary) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TestCoverageSummary
impl Serialize for TestCoverageSummary
impl StructuralPartialEq for TestCoverageSummary