pub struct OverrideFileCoverage {
pub filepath: RelativePathBuf,
pub lines: Vec<OverrideCoveredLineInfo>,
}Expand description
Code coverage overrides per file. [req(“review.coverage”)]
Fields
filepath: RelativePathBufThe file whose coverage data is overridden in a review.
lines: Vec<OverrideCoveredLineInfo>The line information in the file that is overridden.